@@ -1,5 +1,6 @@
 """Support session with Muffin framework."""
 
+import sys
 import functools
 import typing as t
 from inspect import iscoroutine
@@ -13,7 +14,7 @@ from muffin.plugin import BasePlugin
 from muffin.utils import to_awaitable
 
 
-__version__ = "0.9.2"
+__version__ = "0.10.1"
 __project__ = "muffin-session"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -28,7 +29,7 @@ class Plugin(BasePlugin):
     """Provide session's engine for Muffin."""
 
     name = 'session'
-    defaults = {
+    defaults: t.Dict = {
         'auto_manage': False,
         'secret_key': 'InsecureSecret',  # Secret is using for secure the session
         'cookie_name': 'session',
@@ -43,6 +44,10 @@ class Plugin(BasePlugin):
         'login_url': '/login',
     }
 
+    # XXX: Python 3.7
+    if sys.version_info < (3, 8):
+        del defaults['cookie_params']['samesite']
+
     def setup(self, app: muffin.Application, **options):
         """Initialize the plugin."""
         super().setup(app, **options)
